@@ -135,59 +135,71 @@ test_that("`enrichment_chart()` -- produces a ggplot object with correct labels"
         expect_is(g <- enrichment_chart(example_pathfindR_output), "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
 
         # plot_by_cluster
         expect_is(g <- enrichment_chart(example_pathfindR_output_clustered, plot_by_cluster = TRUE),
             "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
 
         # chang top_terms
         expect_is(g <- enrichment_chart(example_pathfindR_output, top_terms = NULL),
             "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
 
         expect_is(g <- enrichment_chart(example_pathfindR_output, top_terms = 1000),
             "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
 
         # change num_bubbles
         expect_is(g <- enrichment_chart(example_pathfindR_output_clustered, num_bubbles = 30),
             "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
 
         # change even_breaks
         expect_is(g <- enrichment_chart(example_pathfindR_output_clustered, even_breaks = FALSE),
             "ggplot")
         expect_equal(ggplot2::quo_name(g$mapping$x), "Fold_Enrichment")
         expect_equal(ggplot2::quo_name(g$mapping$y), "Term_Description")
-        expect_equal(g$labels$size, "# genes")
-        expect_equal(g$labels$colour, expression(-log[10](p)))
-        expect_equal(g$labels$x, "Fold Enrichment")
-        expect_equal(g$labels$y, "Term_Description")
+        
+        labels <- ggplot2::get_labs(g)
+        expect_equal(labels$size, "# genes")
+        expect_equal(labels$colour, expression(-log[10](p)))
+        expect_equal(labels$x, "Fold Enrichment")
+        expect_equal(labels$y, "Term_Description")
     })
 
 test_that("`enrichment_chart()` -- argument checks work", {
